.. _`basf2-example-label`:

Basf2 specific examples
=======================

The following examples are not of interest to the general audience, but only for basf2 users.


Standard Simulation, Reconstruction and some nTuple Generation
--------------------------------------------------------------

.. literalinclude:: ../../examples/basf2/basf2_chain_example.py